@@ -5,6 +5,7 @@
 #' @param data Experimental design data frame with the factors and traits.
 #' @param trait Name of the trait.
 #' @param model The fixed or random effects in the model.
+#' @param drop_na drop NA values from the data.frame
 #'
 #' @description
 #'
@@ -32,15 +33,17 @@
 #' rmout <- outliers_remove(
 #'   data = potato
 #'   , trait ="stemdw"
-#'   , model = "0 + (1|bloque) + geno"
+#'   , model = "0 + treat*geno + (1|bloque) + geno"
+#'   , drop_na = FALSE
 #'   )
-#'   
-#' rmout$outliers
+#' 
+#' rmout
 #'   
 
 outliers_remove <- function(data
                             , trait
                             , model
+                            , drop_na = TRUE
                             ) {
 
   out_flag <- bholm <- NULL
@@ -83,7 +86,12 @@ outliers_remove <- function(data
     dplyr::filter(out_flag %in% "OUTLIER")
 
   nwdt <- cbind(newdt, BHStud_test) %>%
-    dplyr::filter(!out_flag %in% "OUTLIER") %>%
+    mutate({{trait}} := case_when(
+      !out_flag %in% "OUTLIER" ~ as.character(.data[[trait]])
+      , TRUE ~ NA_character_
+    )) %>% 
+    mutate(across({{trait}}, as.numeric)) %>% 
+    {if (isTRUE(drop_na)) {drop_na(data = ., any_of({{trait}}))} else {.}} %>% 
     select({{model_fact}}) %>%
     relocate({{trait}}, .after = last_col())
 
